@@ -2,8 +2,14 @@
 Python/Numeric version of this module was called mpfit. This version was modified to use numpy.
 """
 from __future__ import division, print_function # confidence medium
+
 __version__ = '0.2'
 
+import warnings
+
+warnings.warn("NMPFIT is deprecated - stsci.tools v 3.4.13 is the last version to contain it.")
+
+
 """
 Perform Levenberg-Marquardt least-squares minimization, based on MINPACK-1.
 
@@ -406,9 +412,6 @@ Perform Levenberg-Marquardt least-squares minimization, based on MINPACK-1.
         Translated from MPFIT (Craig Markwardt's IDL package) to Python,
         August, 2002.  Mark Rivers
 """
-from . import numerixenv
-numerixenv.check()
-
 import numpy
 import types
 
@@ -2242,7 +2245,7 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
         if self.debug:
             print('Entering calc_covar...')
 
-        if numpy.rank(rr) != 2:
+        if rr.ndim != 2:
             print('ERROR: r must be a two-dimensional matrix')
             return(-1)
 
