@@ -147,10 +147,11 @@ class WCSObject:
         input exposure's header and provide conversion functionality
         from pixels to RA/Dec and back.
 
-        :Syntax: The basic syntax for using this object is::
+        The basic syntax for using this object is::
 
-            >>> wcs = wcsutil.WCSObject(rootname,header=None,shape=None,
-            >>>                        pa_key='PA_V3',new=no,prefix=None)
+            >>> wcs = wcsutil.WCSObject(
+            ...     rootname, header=None, shape=None,
+            ...     pa_key='PA_V3', new=no, prefix=None)  # doctest: +SKIP
 
         This will create a WCSObject which provides basic WCS functions.
 
